==> kpmcore-1.9.50.tar.xz: kpmcore-1.9.50/src/plugins/dummy/dummybackend.h <==
/*************************************************************************
 *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
 *                                                                       *
 *  This program is free software; you can redistribute it and/or        *
 *  modify it under the terms of the GNU General Public License as       *
 *  published by the Free Software Foundation; either version 3 of       *
 *  the License, or (at your option) any later version.                  *
 *                                                                       *
 *  This program is distributed in the hope that it will be useful,      *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *  GNU General Public License for more details.                         *
 *                                                                       *
 *  You should have received a copy of the GNU General Public License    *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
 *************************************************************************/

#if !defined(DUMMYBACKEND__H)

#define DUMMYBACKEND__H

#include "backend/corebackend.h"

#include <QList>
#include <QVariant>

class Device;
class KPluginFactory;
class QString;

/** Dummy backend plugin that doesn't really do anything.

    @author Volker Lanz <vl@fidra.de>
*/
class DummyBackend : public CoreBackend
{
    friend class KPluginFactory;

    Q_DISABLE_COPY(DummyBackend)

private:
    DummyBackend(QObject* parent, const QList<QVariant>& args);

public:
    virtual void initFSSupport();

    virtual QList<Device*> scanDevices(bool excludeReadOnly = false) override;
    virtual CoreBackendDevice* openDevice(const QString& device_node) override;
    virtual CoreBackendDevice* openDeviceExclusive(const QString& device_node) override;
    virtual bool closeDevice(CoreBackendDevice* core_device) override;
    virtual Device* scanDevice(const QString& device_node) override;
};

#endif

==> kpmcore-3.1.0.tar.xz: kpmcore-3.1.0/src/plugins/dummy/dummybackend.h <==
/*************************************************************************
 *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
 *                                                                       *
 *  This program is free software; you can redistribute it and/or        *
 *  modify it under the terms of the GNU General Public License as       *
 *  published by the Free Software Foundation; either version 3 of       *
 *  the License, or (at your option) any later version.                  *
 *                                                                       *
 *  This program is distributed in the hope that it will be useful,      *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *  GNU General Public License for more details.                         *
 *                                                                       *
 *  You should have received a copy of the GNU General Public License    *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
 *************************************************************************/

#if !defined(DUMMYBACKEND__H)

#define DUMMYBACKEND__H

#include "backend/corebackend.h"

#include <QList>
#include <QVariant>

class Device;
class KPluginFactory;
class QString;

/** Dummy backend plugin that doesn't really do anything.

    @author Volker Lanz <vl@fidra.de>
*/
class DummyBackend : public CoreBackend
{
    friend class KPluginFactory;

    Q_DISABLE_COPY(DummyBackend)

private:
    DummyBackend(QObject* parent, const QList<QVariant>& args);

public:
    void initFSSupport() override;

    QList<Device*> scanDevices(bool excludeReadOnly = false) override;
    CoreBackendDevice* openDevice(const QString& device_node) override;
    CoreBackendDevice* openDeviceExclusive(const QString& device_node) override;
    bool closeDevice(CoreBackendDevice* core_device) override;
    Device* scanDevice(const QString& device_node) override;
    FileSystem::Type detectFileSystem(const QString& deviceNode) override;
};

#endif
